Calculate allocated greenhouse gas emissions (GHG)
Source:R/core_model_aggregation.R
calc_allocated_emissions.RdCalculates the greenhouse gas emissions (GHG) attributable to specific commodities by applying allocation shares to total herd-level emissions.
Details
Allocation shares represent the fraction of total emissions assigned to
each commodity (e.g., meat, milk, fibre).
See run_allocation_module() for additional details.
Allocated emissions are calculated as:
$$value\_allocated = value \times allocation\_share$$
This function is part of the run_aggregation_module().