Skip to contents

Calculates cohort-level meat production outputs over the assessment period based on the number of animals removed from the herd (offtake). The function returns multiple production metrics expressed in live weight, carcass weight, bone-free meat, and meat protein (kg/cohort/assessment period).

Usage

calc_meat_production(
  offtake_heads_assessment,
  live_weight_cohort_at_slaughter,
  carcass_dressing_fraction,
  bone_free_meat_fraction,
  meat_protein_fraction
)

Arguments

offtake_heads_assessment

Numeric. Total number of animals removed via offtake over the assessment period, aggregated to 6 sex–age cohorts (heads/assessment period) (cohorts = FJ, FS, FA, MJ, MS, MA).

live_weight_cohort_at_slaughter

Numeric. Live weight at slaughter for animals removed from the cohort (kg).

carcass_dressing_fraction

Numeric. Ratio of a slaughtered animal's carcass weight to its live weight (fraction).

bone_free_meat_fraction

Numeric. Ratio of bone-free-meat to carcass weight (fraction).

meat_protein_fraction

Numeric. Protein content of bone-free-meat (kg protein/kg bone-free-meat).

Value

A named list with:

meat_production_live_weight_cohort

Numeric . Total meat produced as live weight over the assessment period by cohort (kg/cohort/assessment period).

meat_production_carcass_weight_cohort

Numeric. Total meat as carcass weight (excluding organs, and other by-products after dressing) produced over the assessment period by cohort (kg/cohort/assessment period).

meat_production_bone_free_meat_cohort

Numeric. Total bone-free-meat (excluding bones, organs, and other by-products after dressing and bone removal) produced over the assessment period by cohort (kg/cohort/assessment period).

meat_production_protein_cohort

Numeric. Total meat protein (excluding bones, organs, and other by-products after dressing and bone removal) produced over the assessment period by cohort (kg protein/cohort/assessment period).

Details

Meat production outputs are computed as follows:

  • meat_production_live_weight_cohort is computed as:

    \(meat\_production\_live\_weight\_cohort = offtake\_heads\_assessment \times live\_weight\_cohort\_at\_slaughter\)

  • meat_production_carcass_weight_cohort is computed as:

    \(meat\_production\_carcass\_weight\_cohort = meat\_production\_live\_weight\_cohort \times carcass\_dressing\_fraction\)

  • meat_production_bone_free_meat_cohort is computed as:

    \(meat\_production\_bone\_free\_meat\_cohort = meat\_production\_carcass\_weight\_cohort \times bone\_free\_meat\_fraction\)

  • meat_production_protein_cohort is computed as:

    \(meat\_production\_protein\_cohort = meat\_production\_bone\_free\_meat\_cohort \times meat\_protein\_fraction\)

This function is part of the run_production_module().