Calculate diet ash contribution for a ration component
Source:R/core_model_ration_quality.R
calc_ration_ash.RdCalculates the contribution of a single feed component to diet ash content by weighting feed ash content by its ration composition share.
Arguments
- feed_ration_fraction
Numeric. Proportion of a specific feed component in the total ration, expressed as its fraction of diet dry matter intake (fraction). Within each herd_id and cohort, proportions should sum to 1.
- feed_ash
Numeric. Average ash content by feed component, expressed as a fraction of the dry matter intake (g ash/100g DM).
Details
The ash contribution is defined as: $$ration\_ash = feed\_ration\_fraction \times feed\_ash / 100$$
Ash content is expressed as a percentage (g/100g DM); the result is a fraction.
This function is part of the run_ration_quality_module().