Calculate daily ration intake in dry matter
Source:R/core_model_metabolic_energy_req.R
calc_ration_intake.RdCalculates daily feed intake as dry matter intake (DMI) per animal (kg DM/head/day) from the animal's daily energy requirement and the diet energy density.
Usage
calc_ration_intake(
species_short,
metabolic_energy_req_total,
ration_gross_energy,
ration_metabolizable_energy
)Arguments
- species_short
Character. Code identifying the livestock species. Supported values include:
PGS: pigsCML: camelsCTL: cattleBFL: buffaloSHP: sheepGTS: goats
- metabolic_energy_req_total
Numeric. Total daily energy requirement (MJ/head/day). For CTL, BFL, SHP and GTS this is expressed as gross energy intake requirement (GE). For CML and PGS the function returns the summed daily metabolizable energy requirement.
- ration_gross_energy
Numeric. Average gross energy content of the diet (MJ/kg DM).
- ration_metabolizable_energy
Numeric. Average metabolizable energy content of the diet (MJ/kg DM).
Details
This function follows the IPCC Tier 2 framework. DMI is computed by dividing the appropriate daily energy requirement by the corresponding diet energy content (MJ/kg DM).
Energy expressed as gross energy intake requirement -
CTL,BFL,SHP,GTS:$$ ration\_intake = \frac{metabolic\_energy\_req\_total}{ration\_gross\_energy} $$
Energy expressed as metabolizable energy requirement -
CML,PGS:$$ ration\_intake = \frac{metabolic\_energy\_req\_total}{ration\_metabolizable\_energy} $$
This function is part of the run_metabolic_energy_req_module().
References
IPCC. (2006). 2006 IPCC Guidelines for National Greenhouse Gas Inventories, Volume 4 (AFOLU), Chapter 10: Emissions from Livestock and Manure Management.
IPCC. (2019). 2019 Refinement to the 2006 IPCC Guidelines for National Greenhouse Gas Inventories, Volume 4 (AFOLU), Chapter 10: Emissions from Livestock and Manure Management.