Calculate total metabolic energy requirements
Source:R/core_model_metabolic_energy_req.R
calc_total_metabolic_energy_req.RdCalculates the total daily energy requirement (MJ/head/day) by summing relevant energy partitions (maintenance, activity, lactation, work, pregnancy, growth, fibre, egg deposition).
Usage
calc_total_metabolic_energy_req(
species_short,
metabolic_energy_req_maintenance,
metabolic_energy_req_activity,
metabolic_energy_req_lactation,
metabolic_energy_req_work,
metabolic_energy_req_pregnancy,
net_energy_maintenance_digestible_energy_ratio,
metabolic_energy_req_growth,
metabolic_energy_req_fibre_production,
metabolic_energy_req_egg_deposition,
net_energy_growth_digestible_energy_ratio,
ration_digestibility_fraction
)Arguments
- species_short
Character. Code identifying the livestock species. Supported values include:
PGS: pigsCML: camelsCTL: cattleBFL: buffaloSHP: sheepGTS: goats
- metabolic_energy_req_maintenance
Numeric. Energy required for maintenance, defined as the amount of energy needed to keep the animal at equilibrium such that body energy is neither gained nor lost (MJ/head/day). Expressed as net energy for CTL, BFL, SHP, GTS and as metabolizable energy for CML and PGS.
- metabolic_energy_req_activity
Numeric. Energy required for activity, defined as the amount of energy needed to support animal movement and physical activity (MJ/head/day). Expressed as net energy for CTL, BFL, SHP, GTS and as metabolizable energy for CML and PGS.
- metabolic_energy_req_lactation
Numeric. Energy required for lactation (MJ/head/day). Expressed as net energy for CTL, BFL, SHP, GTS and as metabolizable energy for CML and PGS.
- metabolic_energy_req_work
Numeric. Energy required for work, used to estimate the energy required for draught power for CTL, BFL and CML (MJ/head/day). Assumed to be 0 for other species. Expressed as net energy for CTL, BFL, SHP, GTS and as metabolizable energy for CML and PGS.
- metabolic_energy_req_pregnancy
Numeric. Energy required for pregnancy for pregnant females (MJ/head/day). Expressed as net energy for CTL, BFL, SHP, GTS and as metabolizable energy for CML and PGS.
- net_energy_maintenance_digestible_energy_ratio
Ratio of net energy available for maintenance in the diet to digestible energy consumed (fraction).
- metabolic_energy_req_growth
Numeric. Energy required for growth (i.e., weight gain) (MJ/head/day). Expressed as net energy for CTL, BFL, SHP, GTS and as metabolizable energy for CML and PGS.
- metabolic_energy_req_fibre_production
Numeric. Energy required for the synthesis of fibre for SHP, GTS and CML. Assumed to be 0 for other species (MJ/head/day). Expressed as net energy for CTL, BFL, SHP, GTS and as metabolizable energy for CML and PGS (MJ/head/day).
- metabolic_energy_req_egg_deposition
Numeric. Net energy for egg production (MJ/head/day).
- net_energy_growth_digestible_energy_ratio
Numeric. Ratio of net energy available for growth in the diet to digestible energy consumed (fraction)
- ration_digestibility_fraction
Numeric. Average digestibility of the feed ration, expressed as ratio of digestible to gross energy content (fraction).
Value
Numeric. Total daily energy requirement (MJ/head/day). For CTL, BFL, SHP and GTS this is expressed as gross energy intake requirement (GE). For CML and PGS the function returns the summed daily metabolizable energy requirement.
Details
This component follows the IPCC Tier 2 partitioning approach and the calculation is computed differently depending on whether species energy requirements are expressed as net or metabolizable energy.
Species-specific approach:
Energy requirements expressed as net energy (
CTL,BFL,SHP,GTS)CTLandBFL: $$ metabolic\_energy\_req\_total = \frac{ \left( \frac{ metabolic\_energy\_req\_maintenance + metabolic\_energy\_req\_activity + metabolic\_energy\_req\_lactation + metabolic\_energy\_req\_work + metabolic\_energy\_req\_pregnancy }{REM} \right) + \left( \frac{metabolic\_energy\_req\_growth}{REG} \right) }{diet\_digestibility\_fraction} $$SHPandGTS: $$ metabolic\_energy\_req\_total = \frac{ \left( \frac{ metabolic\_energy\_req\_maintenance + metabolic\_energy\_req\_activity + metabolic\_energy\_req\_lactation + metabolic\_energy\_req\_pregnancy }{REM} \right) + \left( \frac{ metabolic\_energy\_req\_growth + metabolic\_energy\_req\_fibre }{REG} \right) }{diet_digestibility_fraction} $$
Energy requirements expressed as metabolizable energy (
CML,PGS)For these species, the total daily requirement is computed as the direct sum of relevant energy components (MJ/head/day).
CML: $$ metabolic\_energy\_req\_total = metabolic\_energy\_req\_maintenance + metabolic\_energy\_req\_activity + metabolic\_energy\_req\_lactation + metabolic\_energy\_req\_work + metabolic\_energy\_req\_fibre\_production + metabolic\_energy\_req\_pregnancy + metabolic\_energy\_req\_growth $$PGS: $$ metabolic\_energy\_req\_total = metabolic\_energy\_req\_maintenance + metabolic\_energy\_req\_activity + metabolic\_energy\_req\_lactation + metabolic\_energy\_req\_pregnancy + metabolic\_energy\_req\_growth $$
This function is part of the run_metabolic_energy_req_module().
References
IPCC. (2019). 2019 Refinement to the 2006 IPCC Guidelines for National Greenhouse Gas Inventories, Chapter 10: Emissions from Livestock and Manure Management, Equation 10.16.
IPCC. (2006). 2006 IPCC Guidelines for National Greenhouse Gas Inventories, Chapter 10: Emissions from Livestock and Manure Management, Equation 10.16.
See also
run_metabolic_energy_req_module,
calc_metabolic_energy_req_maintenance
calc_metabolic_energy_req_activity
calc_metabolic_energy_req_growth
calc_metabolic_energy_req_lactation
calc_metabolic_energy_req_work
calc_metabolic_energy_req_fibre
calc_metabolic_energy_req_pregnancy
calc_rem_maintenance
calc_reg_growth
calc_ration_intake